Handbook - Gap Junctions
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode, neurons, gap junctions, nervous system

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

GAP JUNCTIONS Click pictures for new window with figure and legend, click again for high resolution image
1 Introduction The gap junctions (electrical synapses) of C. elegans constitute a ubiquitous type of cell-cell contact formed by innexin proteins. The innexins are expressed in almost every cell and while they bear no specific sequence homologies to vertebrate connexins, they form intercellular membrane channels with similarities in structure and function to those in vertebrate tissues. There is distant homology between the innexin genes of C. elegans and the pannexin protein channels of vertebrates (Phelan and Starich, 2001; Baranova et al., 2004; Penuela et al., 2013). Caenorhabditis elegans utilizes gap junctions in different ways in virtually all of its cells (see reviews by: Liu et al., 2006; Bao et al., 2007; Norman and Villu Maricq, 2007; Altun et al., 2009; Simonsen et al., 2014). Here we present molecular information and developmental aspects of gap junction formation and additionally show how gap junctions function in the adult tissues, particularly within the nervous system and motor system. The use of multiple different subunits per channel make the nematodes utilization of gap junctions more sophisticated and complex than what is currently known for vertebrate systems. Physiological studies of nematode gap junctions have mostly been done prior to any knowledge of their complex subunit usage (Stretton et al., 1978; del Castillo et al, 1989), and beg to be redone with consideration of this variable (White, 2003; Liu et al., 2013; Starich et al., 2014). There is still much more to be learned about how these same channel proteins might be utilized in hemichannels rather than as intercellular junctions. The following chapter combines the content of two recent reviews on gap junctions (Hall, 2016 and Hall, 2017).
2 Expression and Structure Innexin genes in C. elegans show a similar diversity in number and organization to the connexin family in vertebrates, and are surprisingly numerous compared to some other invertebrates such as the fruit fly Drosophila or the planarian Dugesia. The C. elegans genome encodes 25 innexin genes, and virtually every cell type in the animal appears to express at least one innexin protein, often expressing multiple different innexin genes per cell (Altun et al., 2009). The multiplicity of innexin expression underlies the formation of heterotypic and heteromeric gap junctions, perhaps several types per cell (Liu et al., 2013; Starich et al., 2014). Heterotypic channels offer unique opportunities for developmental modulation of channel properties in a manner parallel to what is becoming well known for other forms of intercellular membrane channels, such as glutamate or NMDA receptors (Liu and Zukin, 2007; Rodenas-Ruano et al., 2012). Although gap junctions can appear essentially equivalent even at the ultrastructural level using standard electron microscopy (TEM) in thin sections, the junctions of invertebrate tissues stand apart from those in vertebrates when investigated by the freeze fracture (FF) technique (Staehelin, 1974; Lane et al., 1977). Vertebrate gap junction channels appear to be grouped into well-ordered clusters of intramembrane particles (IMPs), with six-fold symmetry reflecting their internal composition of six subunits per hemichannel. Invertebrate gap junctions often show larger IMPS and some may utilize more subunits per hemichannel (GapjunctFIG 1A). INX-6 channels in the C. elegans intestine involve 8 subunits per hemichannel rather than 6, forming larger IMPs and probably a wider channel pore size (Oshima et al., 2013, 2016) (GapjunctFIG 1B). Oshima et al. (2016) argue that since many invertebrate gap junctions feature relatively large IMPs when viewed by FF, this 8-fold arrangement may be commonplace for innexin-based channels. GapjunctFIG 1: Models of gap junction channels. A. Classification of gap junction channels according to their subunit composition as homomeric, heterotypic or heteromeric (after Koval et al., 2014). B. Model of the homomeric innexin channel in C. elegans intestine (after Oshima et al., 2016). C. Models of possible innexin heteromeric channels in bodywall muscle, assuming 6 subunits per hemichannel (after Liu et al, 2013). D. Models of possible innexin heteromeric channels in distal gonad, assuming 8 subunits per hemichannel (after Starich et al, 2014). At present we do not know the number of subunits per channel, and the possible combinations shown here are among many possibilities. Vertebrate gap junctions always consist of IMPs cleaving to the �P-face� of the plasma membrane replica, with corresponding �E-face� pits seen in a matching pattern to the IMPs. However, invertebrate gap junctions often consist of mixtures of particles and pits in both replica faces, sometimes with most IMPs cleaving to the E-face (Lane et al., 1977) (GapjunctFIG 2A&B). The planarian Dugesia was the first invertebrate where it became clear that individual tissues could show unique patterns in this E-face/P-face distribution when compared by FF (Quick and Johnson, 1977). Early FF results in C. elegans revealed a similar diversity (Hall, 1987). Although the IMPs in many nematode tissues appear to show similar diameters and similar packing densities, the ratio of E-face to P-face particles is tissue specific and the number of IMPs per array varies widely (GapjunctTABLE 1).
| Intramembrane Particles
Nematode Tissue | P-Face (%) | Packing Density | Plaque Size
Hypodermis | 90 | Low | Medium
Muscle | 90 | High | Large
Intestine | 90 | High | Large
Neuron | ~50 | Low | Small
Distal germline | 90 | Low | Small
Proximal germline | 80 | High | Large
GapjunctTABLE 1: Gap junction features viewed by freeze fracture. Freeze fracture data from Hall, 1987; Hall et al., 1999; Starich et al., 2014; and Hall, unpublished. Exact diameters of gap junction IMPs or their pore sizes would require much higher resolution studies, such as those carried out for INX-6 in intestine (cf., Oshima et al., 2016). GapjunctFIG 2: Gap junction channels are clustered in the plasma membrane. A. Schematic diagram depicting a small array of gap junction subunits lying in the plasma membranes of two closely opposing cells. The gap consists of the narrow space between the outer layers of the opposing plasma membranes, which is periodically spanned by the gap junction channel subunits. In a freeze fracture replica the fast frozen membranes are ripped open to separate the inner and outer layers of a single plasma membrane. Individual gap junction channels pull out of one layer or the other, revealing an array of intramembrane particles and pits that shows the close packing of GJ channels within the membrane, as in panel B. A typical nematode gap junction does not fracture as cleanly as for a vertebrate gap junction, where one fracture face would show all pits, and the other face all particles. When the ionic tracer lanthanum is infiltrated into such a junction before fixation, the lanthanum will precipitate in the narrow space between the two plasma membranes. Gap junction channels will exclude this tracer as they cross the gap, leaving a negative stain that again shows the packing of the channel array as white dots against the black tracer, as in panels C & D. B. N2 F/F Sample 4 M5 005286 (Hall) Freeze fracture replica of an adult wild type animal showing several arrays of particles and pits (arrowheads) in a hypodermal membrane where large gap junctions have formed. C. C. elegans image 011 of 11/19/2007 (McKee). Low power view of intestine where lanthanum tracer has infiltrated between two intestinal cells (INT) at their membrane border. D. C. elegans image 014 of 11/19/2007 (McKee). Higher power view of a nearby portion of the same sample as in panel C, with arrowheads pointing to locales where the array of GJ channels are negatively stained. Their visibility depends not only on the quality of the stain penetration, but the exact angle of the thin section vs the plasma membrane. Only where the plasma membrane is seen lying en face within the section does the particle array become visible thus the true size of any one particle array might be much larger than what can be seen from this single section. Lanthanum tracer images are shown courtesy of Mary McKee and Emily Troemel. Given the small size of nematode cells, most IMP arrays are necessarily relatively small. Some classes of gap junctions in C. elegans are so small in size that they can only be revealed by the FF technique, but are never large enough to be seen in TEM by thin section (Starich et al., 2014). The small size of neuronal gap junctions in C. elegans has been a major concern in trying to describe the full connectome of the nematode nervous system (Hall, 1977; White et al., 1986; Hall and Russell, 1991; Jarrell et al., 2012). Another high resolution method for discovering these arrays of IMPs uses infiltration by lanthanum salts (GapjunctFIG 2C,D). Lanthanum infiltration permits one to see the arrays of channels by negative staining, where electron dense lanthanum penetrates the narrow space between opposing plasma membranes at a gap junction, but is excluded by the channels themselves, as those channel subunits project all the way across that intercellular space (Revel and Karnovsky, 1967). Careful anatomical studies of the entire adult of both sexes have revealed that gap junctions can be seen in virtually all tissue types, and in almost every cell in C. elegans (Hall and Altun, 2008). In some larval tissues, gap junctions are seen early in development, only to disappear when groups of epithelial cells fuse to form larger syncytia in the adult (Nguyen et al., 1999). Large gap junctions can allow transfer of fluid, ions or small molecules between dissimilar cell, as in the excretory system (Hall, 2016; Hall and Altun, 2008). When viewed globally across C. elegans tissues, the pattern of innexin expression across neighboring cells suggests that heteromeric and heterotypic gap junction channels will be common in C. elegans (Altun et al, 2009). The amino acid sequences of the innexins of C. elegans (and other invertebrates) do not resemble the sequences of gap junction proteins of vertebrates, known as �connexins�. However they do share overall similarity with the �pannexins� of the vertebrate world (Baranova et al., 2003). The human genome includes 3 different pannexin genes, none of which seems to form true gap junctions (Chiu et al, 2014; Retamal and Saez, 2014). However, pannexins have been implicated in acting as membrane ion channels that do not link to similar channels in an opposing membrane, but instead act as �hemichannels� (Bruzzone et al, 2003; Sosinsky et al, 2011; Retamal and Saez, 2014). Such hemichannels are proving important in a variety of human diseases, including inflammation, ischemia and tumor genesis (Chiu et al, 2014). Hemichannels in vertebrates can sometimes function as stretch receptors (Richter et al., 2014). The nematode innexin unc-7 can also act as a hemichannel in several different sensory neurons, including the touch cells (ALM, PLM, etc) and in the harsh touch cells (PVD), and in both instances the unc-7 hemichannel acts as a receptor either for gentle touch, harsh touch, or both (Walker and Schafer, 2020). An earlier report by Bouhours et al (2011) had previously demonstrated that unc-7 may also act as a hemichannel at neuromuscular junctions in C. elegans. Remarkably, when the human pannexin 1 sequence is used to replace UNC-7 protein in the touch neurons of an unc-7 mutant, pannexin1 hemichannels can rescue touch sensitivity in ALM and PLM (Walker and Schafer, 2020). 3 Development The roles that gap junctions play in tissue development may be diverse, but few innexin mutants have proven to be lethal, although some alleles do produce low levels of dead embryos. For instance, inx-3 mutant alleles yield occasional dead embryos in which the pharynx becomes detached from the intestine, apparently due to the weakening of tissue linkages at the pharyngeal valve (Starich et al., 2003). Indeed, INX-3 protein is expressed everywhere in the early embryo, and can be detected in small plaques ubiquitously even before the embryo begins gastrulation. It appears that at this early stage, all cells may be communicating with neighbors via gap junctions, at or near the time when these cells are undergoing �global cell sorting� to migrate from the place of their birth to form functional groupings before tissues begin to form (Bischoff and Schnabel, 2006). Sister cells often have different fates, and some individual cells always undergo apoptosis. For development to progress, many cells must separate from their sisters after cell division and migrate to locate their proper partners before tissue morphogenesis can begin. Although unproven, it seems reasonable that gap junctions may play an accessory role in intercellular communication among undifferentiated cells to foster cell sorting, or to enhance cell clustering at the outset of morphogenesis. Stronger coupling might then help to synchronize or coordinate the morphogenesis within cell groups. Alternately, gap junctions may play an adhesive role during cell motility at this early stage in embryogenesis. Coincident with the early wave of INX-3 expression, INX-8 and INX-9 expression in the early embryo is associated with proper maturation of the eggshell (Starich et al., 2014; Stein and Golden, 2015). Mutations in either gene lead to leaky eggshells that permit diffusion of DAPI into the early embryo, with defects noted as early as the 4-cell stage. Other early defects in these mutants include failures in cytokinesis during early cell divisions, and the extrusion of polar bodies just beneath the eggshell. As tissue development proceeds, virtually all cell types express one or more innexins, and gap junctions have been detected anatomically at the borders of most epithelial cells where they contact their neighbors within an epithelium (GapjunctFIG 3). As the early embryonic pharynx defect in inx-3 mutants suggests, gap junctions may also play a structural role in tissue integrity by linking one tissue to its neighbor, although adherens junctions are also widely utilized in the same role (Koeppen et al., 2001). GapjunctFIG 3C shows an example from the adult pharynx where an adherens junction and a gap junction lie side by side to help in attaching muscle and support cells tightly together. The nematode body plan involves many syncytial epithelia, and gap junctions have been seen by TEM along cell borders in advance of targeted cell fusions (including self-fusions) both in the embryonic excretory system (Stone et al., 2009; Abdus-Saboor et al., 2011; Mancuso et al., 2012), and in hypodermal cells in the late larval male tail (Nguyen et al., 1999). Thus, communication across gap junctions may help to guide certain steps in tissue morphogenesis. GapjunctFIG 3: Gap junctions seen in thin sections by TEM. A. High magnification view of adult dorsal nerve cord; white arrowhead shows chemical synapse; black arrowhead shows GJ between muscle arms. BWM, bodywall muscle; hyp, hypodermis. (Image source: [Beth Chen; Hall lab archive] N2U Z152.) Scale bar is 0.5 micron. B. Wild type adult amphid nerve; black arrowheads show small GJ between two amphid dendrites (den). (Image source: [Hall] N513A J3 F579.) Scale bar is 0.5 micron. C. Adult pharynx in unc104-2 animal showing AJ (white arrows) and GJ (black arrowhead). Both junctions occur between a pharyngeal muscle (pm) and a marginal cell (MC). (Image source: [Hall] U3 M498.) Scale bar is 0.5 micron. D. Adult excretory canal showing two GJs connecting the excretory canal process to hypodermis (hyp)(black arrowheads). (Image source: [Matthew Buechner; Hall lab archive]). Scale bar is 0.5 micron. Transitory gap junctions have been shown to occur between developing neurons at a time when they are choosing between alternate cell fates (Chuang et al., 2007). The innexin gene nsy-5 is expressed in a cluster of neuron cell bodies in the lateral ganglion during late embryogenesis and early L1 stage, perhaps 12 neurons per side. Mutations in nsy-5 cause errors in the specification of the AWC neurons (AWCL and AWCR), where generally one cell chooses the AWC-ON cell fate while the opposite cell adopts an AWC-OFF fate. Gap junctions encoded by the nsy-5 innexin actually link multiple neurons in each lateral ganglion, including AWC, ASH and AFD during embryogenesis, but the AWC fate choice is the best described event requiring these intercellular junctions. After the L1 stage, the expression of NSY-5 protein diminishes and protein expression is not known to persist into later larval stages except in a few lateral neurons, including ASH, but not AWC (Chuang et al., 2007). Indeed, the reconstructions of adult lateral ganglia (White et al., 1986) failed to note any gap junctions among these neuronal cell bodies, but TEM studies of the late embryo did find gap junctions linking ASH to AWC, and AFD to ASH on each side (Chuang et al., 2007). Indeed, TEM evidence for these junctions was not found even in the L1 larval stage, suggesting that their role in cell fate choice has been accomplished during late embryogenesis. 4 Function 4.1 Muscle There are a handful of major groups of muscles in the animal, and within each grouping, gap junctions prominently link homologous (or related) muscles to their immediate neighbors (GapjunctFIG 3 and GapjunctFIG 4). This underlies coordinated contractions passing along the length of various body structures during normal behavior, or which operate during more complex sequential events, such as pharyngeal contractions during food consumption, egg-laying by the hermaphrodite, defecation by specialized tail muscles, and the male tail�s discrete sequence of mating behaviors involving many different muscle groups. (For overview see Hermaphrodite Muscle System - Introduction.) GapjunctFIG 4: Gap junctions link muscle cells into functional units. A. Pharyngeal muscles fall into 8 segmental sets, pm1-pm8, with gap junctions (red symbols) linking neighboring segments to one another. Additional gap junctions link all muscles within a segment indirectly for pm2-pm7, via local gap junctions to marginal cells (not shown). Waves of radial contractions pass quickly along the pharynx, even without chemical synaptic input, causing widening of the central lumen. Each segment has been pulled slightly apart graphically to show where gap junctions link them to neighboring segments. Anterior is to the left in each panel. B. Head and bodywall muscles are arranged in almost segmental fashion, with gap junctions connecting all neighboring muscles, both in L/R groups, and linearly along the head and bodywall. Most gap junctions occur on extended muscle arms, as highlighted in panel C. Waves of contraction pass along the body, causing local shortening of either dorsal or ventral muscles, while the opposing quadrants relax in the same locale. View from left aspect at low power, showing only the left side BWM quadrants; compare to panel C showing all four BWM quadrants. C. Bodywall muscles (BWMs) contact neighbors via specialized long thin muscle arms extending medially, where they exchange gap junctions with other muscles, and receive neuromuscular junctions from motor axons lying in the two motor nerve cords (shown in red). White circles mark locales where neuromuscular junctions and gap junctions occur at dorsal and ventral muscle plates. D. Three types of specialized (non-equivalent) muscles for defecation in hermaphrodite tail extend muscle arms to the surface of pre-anal ganglion (shown in pale red). White dotted circle indicates zone where overlapping muscle arms form gap junctions with one another, and receive neuromuscular junctions from motor axons. 4.1.1 Pharynx The pharynx is responsible for the ingestion and preliminary processing of its main food source, small bacteria, by very rapid contractions of coordinated muscle groups that are well connected by gap junctions (see Hermaphrodite Alimentary System - Pharynx). Pharyngeal muscle groups lie in eight consecutive segments along the alimentary canal (GapjunctFIG 4A and GapjunctFIG 5). Muscles are linked within each set to all the other muscles in their segment via gap junctions to marginal cells (which separate muscles within each segment) (GapjunctFIG 3), and then linked again to muscles in the adjacent segment along the chain (Albertson and Thomson, 1976; Altun et al., 2009). These pharyngeal gap junctions underlie extremely fast radial contractions during feeding to sweep food items along the alimentary canal (Trojanowski et al., 2016). Virtually all pharyngeal muscle groups are organized in segmental fashion, and connected to their neighboring segments, including support cells, by a multiplicity of innexin channels (GapjunctFIG 5). Pharyngeal contractions are too rapid to be explained by chemical synaptic inputs from motor neurons, although pharyngeal neurons may influence the pharynx to change from one mode of action to the next (Raizen and Avery, 1994; Trojanowski and Fang-Yen, 2015). Instead, spontaneous contractility of the individual muscle types must drive the rate of action. It has been shown that virtually all pharyngeal neurons can be laser-ablated, individually or en masse, without abolishing the basal rhythm of muscle contraction (Avery and Horvitz, 1989). Pharyngeal muscles are divided into eight small groups of cells along the length of the organ (GapjunctFIG 3). Within one cell group (segment), all muscles appear to express the same set of innexins, and in virtually all cases they express several innexins either at high levels or at lower levels (Altun et al., 2009). Along the length of the pharynx, neighboring segmental groups express different assortments of innexins, so that heteromeric gap junctions between segments seem likely to be the rule here rather than the exception (GapjunctFIG 5). GapjunctFIG 5: Innexin expression pattern in the pharynx. Expression patterns for innexin genes are mapped vs the pharyngeal muscle segments, pm1 to pm9, illustrating which are highly expressed (dark bars) or weekly expressed (lighter bars) in the adult hermaphrodite. While many muscles express similar sets of innexins, each segment of pm muscles tends to express a different combination than its nearest neighbors. Within a segment, pharyngeal muscles lie in cell pairs which are often syncytial to their nearest neighbor, and form gap junctions to nearby marginal cells (GapjunctFIG 3C). Between segments, each muscle cell forms gap junctions to the muscles in the neighboring segment. Arcade cells, purple; pharyngeal epithelium (pe) and pm muscles (1-8), green; valve cells, brown; intestine, pink. 4.1.2 Bodywall Muscles In the bodywall muscles along the length of the animal, 95 muscles are grouped into four quadrants, with a double row of muscles lying within each quadrant, effectively creating 12 segments along the main body axis (Hall and Altun, 2008; Hermaphrodite Muscle System - Somatic Muscle). Spindle-shaped bodywall muscles extend sarcomeres along the bodywall, and also form unique thin extensions called �muscle arms� to reach medially towards the �muscle plate� (GapjunctFIG 4B&C) (White et al., 1976). These body muscles all express at least 6 innexins per cell, generally including the same set in all muscles for any stage in development (Liu et al., 2013). The cells are electrically coupled by gap junctions that are restricted to �muscle arms� that extend from each cell towards either the dorsal or ventral motor nerve cord. Here each muscle arm is contacted by neuromuscular junctions (NMJs) from several categories of principal motor neurons (White et al., 1976; Liu et al., 2006; Hall and Altun, 2008). Where present, muscle arms also form prominent sets of gap junctions among themselves. Thus each muscle is linked to all its nearest neighbors on the dorsal side (or on the ventral side), including left/right dorsal or ventral pairings, but never reaching across the divide between dorsal and ventral quadrants (GapjunctFIG 4B&C). These gap junctions at muscle arms also link muscles �segmentally� along the body to its anterior and posterior nearest neighbors. As a result, muscles lying with each muscle quadrant can conduct action potentials from head to tail or vice versa, depending on local activities that initiate a contractile wave in either the tail or the head to be passed along the body (White et al., 1976; Hall and Altun, 2008; Liu et al., 2006; Liu et al., 2011). Although the gap junctions along the major nerve cords represent the principal means to couple muscles in the four quadrants, there are additional gap junctions found between close neighbors within each muscle quadrant, both among the head muscles (GapjunctFIG 6B) and among bodywall muscles of the rest of the body (White et al., 1986; Qadota et al., 2017). These additional junctions occur on lateral cell membranes amidst the sarcomere regions. They cannot link L/R pairs, nor dorsal/ventral pairs, but only close neighbors within a row within one quadrant. Their relative importance in control of muscle contractions is not understood. The layout of neuromuscular junction inputs to all bodywall muscle cells within a �segment� should insure that all nearby cells on the ventral side (i.e. both ventral quadrants) of the body will act in synchrony, and antiphasic to all muscle cells within the corresponding segment on the dorsal side. The neuromuscular junctions from a fascicle of motor axons are grouped near muscle arm branches in a manner at each motor nerve�s �muscle plate� where all muscles within the ventral segment may receive some fractional share of each quantal release of neurotransmitter at the muscle plate (Liu et al., 2006), and similar sharing of transmitter release occurs at the dorsal muscle plate for all dorsal bodywall muscles. While these multiplex neuromuscular junctions should help to keep all muscles in synchrony locally, there is perhaps a stronger input via electrical signaling among the converging muscle arms themselves. Moreover, since each muscle cell tends to have arms extending from the extreme ends of the full cell length, and because there is some overlap at these endpoints to muscles of the next �segment�, electrical signals should rapidly conduct within a quadrant from muscle to muscle along the length of the body to modulate contractility of the whole animal and its body shape. Genetic knockdown of any of six different innexin genes can partially inhibit this coupling, but there is no single innexin knockout that can fully extinguish coupling, as measured by intracellular recordings in a partially dissected preparation (Liu et al., 2013). Among these six innexins, the patterns of physiological deficits judged from such recordings suggest that there may be two different classes of heteromeric gap junctions here, one class involving two different innexins, and the second class involving four other innexins (GapjunctFIG 1B). 4.1.3 Head Muscles Head muscles use gap junctions to link all muscle cells in each of the four quadrants to one another within the quadrant, and via muscle arms extending near the anterior pharynx, contacting other muscle quadrants and the GLR support cells along the inner surface of the nerve ring (GapjunctFIG 6; Hermaphrodite Muscle System - GLR cells). GLRs are linked via gap junctions to each other, and also to a set of four RME motor neurons from the nerve ring. Importantly, the four muscle quadrants in the head can still operate somewhat independently from one another, so that the animal can control head motions in all directions, unlike the restricted range of motion possible for other bodywall muscles. GapjunctFIG 6: Muscle arms of the head muscles are linked by gap junctions. A. Diagram showing two stylized head muscle arms (dark green) approaching nerve ring. Muscle arms from the 32 muscles in the head and neck project onto the inside surface of the nerve ring in a highly ordered fashion. Their terminal branches lie between the processes of GLR cells (golden yellow) on the inside and the motor neurons of the nerve ring (dark red and purple) on the outside. Arms from the somatic head muscles run posteriorly until they reach the posterior nerve ring region. The arms from each muscle row then make an anterior arc of about 45� and extend inward to reach between the outside surface of the GLRs and the inner surface of the neural plate. This inward turn involves close apposition to the GLR cell bodies. In the neck, somatic muscles extend arms both to the nerve ring and to either the ventral or dorsal nerve cords where they receive additional synapses (not shown). (Light green) pharynx; (orange) basal lamina. B. GLR cells make extensive gap junctions (red bars) to the muscle arms and to RME neurons as shown. For stylistic reasons, RME processes are shown inside the GLR cell layer. In actuality, they lie outside the GLRs and muscle plate. There are also gap junctions between RME neurons and between the muscle bellies of the muscles, occurring on lateral cell membranes where two muscles meet within the quadrant. No gap junctions are seen between the muscle arms of cells within the same quadrant, but gap junctions exist between arms of cells in different quadrants. (Based on White et al., 1986.) 4.1.4 Sex-specific Muscles 4.1.4.1 Gonad Sheath and Spermatheca Contractile elements of the somatic gonad (known as the gonad sheath) (see Hermaphrodite Reproductive System - Somatic Gonad) squeeze on the germline to force this tissue into a cylindrical shape. Somatic sheath cells are connected by gap junctions to their left/right homologues, and segmentally to other sheath cells along the length of the gonad (cf. SomaticFIG 6D) (Hall et al., 1999). Progressive waves of contraction by the sheath are thought to help push germ cells proximally, towards the spermatheca. The somatic sheath cells closest to the spermatheca also form large (transient) gap junctions to the primary oocyte, in the region closest to where the oocyte will be fertilized (cf. SomaticFIG 6C). The larger gap junctions connecting sheath cell 5 to the primary oocyte coordinate internal activities within the oocyte (seen as swirling motions by light microscopy). Rhythmic squeezing by sheath cell 5 forces the primary oocyte towards the spermatheca when it is ready for fertilization (Hall et al., 1999). Separately, sheath cells and the distal tip cell are each linked by hundreds of tiny gap junctions to the underlying germ cells (Starich et al., 2014). The smaller gap junctions between somatic gonad cells and developing germ cells help govern germ cell maturation (Starich et al., 2014). Gap junctions between all cells of the spermatheca help these cells to contract radially in unison to allow entry of the primary oocyte (cf. SomaticFIG 9EF) (Hall and Altun, 2008). But there are no synaptic connections between the nervous system and these muscular elements of the ovary. 4.1.4.2 Vulva, Uterus and Male Sex Muscles Sex-specific muscles of the hermaphrodite vulva and uterus are heavily linked by gap junctions, as are the specialized sex-specific muscles of the male tail (White et al., 1986; Sulston et al, 1980; Jarrell et al., 2012) (see Hermaphrodite Reproductive System - Egg-laying Apparatus and Male Muscle System - Male Specific Muscles). Thus, homologous muscles can operate coordinately, and related muscle groups can act sequentially, in quick succession. Some of these contractions can be vigorous and rapid, synchronized via gap junctions, acting much faster than ongoing neuronal patterns. A limited set of neuromuscular junctions link the hermaphrodite nervous system to a few members of the vulval muscles, and indirectly influence the uterine muscles via muscle-muscle gap junctions (cf. EggFIG 13) (White et al., 1986). Chemical neuromuscular junctions to the male tail�s sex muscles are more elaborate, but gap junctions are extensive among all these sex muscles (cf. MaleMusFIG 30, 31 & 32). 4.1.4.3 Defecation Muscles Defecation muscles in the tail operate in coordinated fashion to open the rectal valve and inflate the rectum during defecation (see Hermaphrodite Alimentary System - Rectum and Anus and Male Alimentary System - Defecation Muscles). These actions are governed by several non-equivalent muscles, linked by muscle arm extensions to form gap junctions among themselves in the same zone where they receive neuromuscular junctions from a single motor axon (DVB) (Hall and Altun, 2008) (GapjunctFIG 4D). 4.2 Somatic Gonad and Germline Complex expression patterns for multiple innexins have been seen in small gap junctions between germline and somatic gonad, with several important developmental consequences. The somatic sheath cells and distal tip cell create a niche environment required for the development of the germline (Hall et al., 1999; Byrd et al., 2014; Starich et al., 2014) (see Hermaphrodite Reproductive System - Somatic Gonad and Reproductive System - Germline). Although larger gap junctions have been found between germline and soma in the proximal arm of the gonad (Hall et al., 1999), a new class of very small gap junctions has been discovered in the distal arm using freeze fracture (FF) and antibody staining. In the distal gonad arm, all individual junctions are too tiny to be discerned by standard TEM in thin sections (Starich et al., 2014). Some of these junctions connect the distal tip cell to the dividing germ cells at the distal end of the gonad arm, while similar small junctions connect the somatic sheath cells to the developing germline closer to the bend in the gonad arm (aka the �reflex�). These gap junctions individually are composed of very small numbers of channels (IMPs per array seen by FF), but are collectively numerous where they connect germ cells to the overlying somatic gonad. Genetic knockdown of any one of five innexin genes leads to systematic defects in germ cell maturation, and the evidence suggests that a typical gap junction channel consists of two different innexin proteins in one hemichannel (on the germline side) and a different pair of innexin proteins in the opposite hemichannel (on the gonad sheath side) (GapjunctFIG 1D). The mixture of innexin usage differs gradually along the length of the gonad arm, so that a fifth innexin gradually substitutes at hemichannels at the opposite end of the extended chain of sheath cells. Communication via innexin channels here is necessary for the germline cells to switch from mitosis to meiosis as they move along within the gonad arm. Interestingly, since these individual germ cells each slowly move relative to the overlying gonad sheath, they must break and reform gap junctions continuously as they traverse the length of the gonad arm and around the bend towards the uterus. The same germ cells are also connected to nearby neighbors within the germline via a central syncytium, the acellular �rachis� (Hall et al., 1999). This open door between all germ cells negates the chance that their gap junctions are allowing electrical signals to propagate, but to allow small molecules to be relayed between soma and germline. The dynamics of this situation are quite exciting, and much remains to be explored about how these gap junctions operate. 4.3 Excretory Canal Epithelia Cells Besides their roles in electrical signaling, gap junctions can permit the transfer of small molecules or fluid between tissues. This is well established for connexin-based junctions in vertebrates (Goldberg et al., 2004), but is not well established for many invertebrate innexin channels. The relatively large physical pore size of some innexin channels should favor passage of larger molecules and solutes (cf. Oshima et al., 2013, 2016). Although the permeability and gating of most innexin channels remains to be carefully explored, some prominent C. elegans gap junctions are already implicated in metabolic processes. For instance, the gap junctions between the excretory canal cell and the hypodermis are especially large and collectively occupy a substantial fraction of the membrane surface area where these two tissues meet (GapjunctFIG 3D) (Buechner et al., 1999; Hall and Altun, 2008). The canal cell extends lateral arms from its cell body to the far reaches of the head and tail, and operates as the kidney for C. elegans, removing excess fluid from the body and excreting this fluid through the excretory duct (see Hermaphrodite Excretory System). Deeply embedded into the surrounding hypodermis, the excretory canals collect fluids, potentially via their prominent gap junctions with the hypodermis. Those fluids are then filtered via the elaborate canaliculi from the canal cytoplasm into the luminal space within the extended canals, before export via the excretory duct. Mutations that disrupt the continuity of the excretory duct cause lethal consequences in the embryo and early L1 larval stage, due to a fluid buildup that swells the animal into a �lethal rod� phenotype (Stone et al., 2009). Some mutant alleles in inx-12 and inx-13, the two main innexins expected to form the heterotypic junctions between hypodermis and the canal cell (Altun et al., 2009), also result in dead L1 larvae exhibiting lethal rod morphology (Todd Starich, pers. comm.). Although there are other possible explanations, these results suggest that INX-12/INX-13 junctions may facilitate water transport from hypodermis to canal cell. Many classes of epithelial cells with C. elegans are also linked to their nearest neighbors via gap junctions (Hall and Altun, 2008). Depending on the cell type, these junctions may be large or small, but many can be seen easily by TEM. This is true for hypodermis, intestine, and the anterior epithelial cells of the buccal cavity and pharynx, none of which is expected to electrically excitable. In each case, it seems more likely that cells within an epithelial compartment can exchange small molecules to like cells. The small gap junctions discussed above between soma and germline in the nematode gonad also seem to involve a metabolic relationship rather than electrical signaling. In the case of the intestine, a calcium wave is seen to pass along the chain of intestinal cells via homomeric INX-16 gap junctions that help to coordinate the defecation cycle (Peters et al., 2007). Additional innexins are also expressed by the intestinal cells that still permit dye coupling even in inx-16 mutants, but INX-16 alone seems to be required for normal propagation of calcium waves (Peters et al., 2007).
4.4 Nervous System Gap junctions within the nervous system connectome play diverse roles (see Hermaphrodite Nervous System). Sometimes they mimic connectivity patterns created by chemical synapses. But in other places, as in some muscles, gap junctions play a unique role in coupling arrays of cells, either to synchronize activities, or to provide a pathway to propagate signals independent from the chemical synapse network (Liu et al., 2011). Although there are only 302 neurons (see Individual Neurons for complete list) and 56 glia in the adult C. elegans hermaphrodite (White et al., 1986), the diversity of innexin expression within them is currently unmatched in any other model organism. Fully 20 of the 25 innexin genes have been shown to be expressed in one or more cells in the nervous system (Altun et al., 2009). Some innexins appear to be expressed in a very restricted set of cells. INX-14 is expressed only in the GABAergic inhibitory motor neuron classes, DD and VD. INX-5 is expressed mostly in glial cells, but in very few neurons. INX-2 is expressed only in AVK, and INX-1 only in AIB and briefly in AIY neurons. However, eight innexin genes are expressed in 15-30 neuron classes each. Furthermore, some neurons express groups of different innexins at once, and a few neurons may express as many as a dozen innexin genes. As virtually all of the 302 neurons are expected to form gap junctions with other neurons, the issue of heteromeric and heterotypic channels arises immediately. Early hints for innexin mixtures were suggested from genetic studies of �uncoordinated� animals, where single mutations of different innexin genes gave rise to no obvious phenotype, or to only mild or moderate dysfunction in neurons and muscles (Starich et al., 1996). This suggests that redundancies must blunt single gene mutant phenotypes. Despite trouble in finding the smallest junctions by TEM, about 6,000 neuronal gap junctions have been identified in the hermaphrodite, and about 10,000 in the adult male (White et al., 1986; Hall and Russell; 1991; Jarrell et al., 2012; Cook et al., in prep.). In many instances within the nematode connectome, one finds that the pattern of gap junction connectivity is quite similar or parallel to the pattern of chemical synaptic contacts (White et al., 1986). However, there are certain levels in sensory processing where gap junctions tend to dominate. For instance, a �hub-and-spoke� pattern has been suggested for the convergence of multiple head sensors to communicate via gap junctions onto a single interneuron, RMG (Macosko et al., 2009) (GapjunctFIG 8). This arrangement may facilitate coordination of several classes of sensory neuron activities, allowing the level of RMG activity to synchronize or facilitate the animal�s responses to different modes of input towards a common output. In this case, RMG activity is apparently governing the animal�s choice between social behavior and solitary behavior, i.e. encouraging the animal to aggregate with other nematodes. Elsewhere gap junctions ought to allow for better synchronization and faster responses in decision making since synaptic delay is minimized. 4.4.1 Synapses between layers As one inspects intercellular signals flowing from sensory cells to interneurons and then motor neurons (White et al., 1986; Hall and Russell; 1991; Jarrell et al., 2012; Faumont et al., 2012; Varshney et al., 2011), much of the general pattern is produced by chemical synapses. Output from motor neurons onto muscles (NMJs) is limited mostly to chemical signaling. Only a minority of contacts between neuron layers involves gap junctions, and their pattern of contacts is often similar to the chemical synaptic network (GapjunctFIG 7). One difference is that chemical synapses in C. elegans tend to form as dyads, where one presynaptic neuron simultaneously synapses onto 2 or more postsynaptic neurons (White et al., 1986; Hall and Russell; 1991). Gap junctions must occur as one to one cell contacts, so that a neuron seemingly cannot choose multiple gap junction partners at once. Nevertheless, gap junction partnerships operating between cell layers are often the same as principal choices for chemical synaptic partnerships. Although we still do not understand how most neurons choose those partners (Emmons, 2016; Kim and Emmons, 2017), the same intercellular mechanisms might be used to recognize suitable partners for both chemical and electrical synapses. The most well studied gap junctions between two neuron layers are those linking the command interneurons (or �premotor neurons�) of the ventral nerve cord to motor neurons along the same cord, controlling contractions of bodywall muscles (White et al., 1986; Kawano et al., 2011) (GapjunctFIG 7). In this instance, information flow involves parallel use of both chemical synapses and gap junctions. While AVA interneurons connect to all class A motor neurons in the nerve cord, AVB interneurons connect to all class B motor neurons. In the absence of functional electrical connections (encoded by unc-7 and unc-9 genes for these heteromeric gap junctions), mutant animals (unc-7 or unc-9 , or the double mutant) are unable to propagate smooth forward or backward motions, but instead show �kinking� (severe body bending) in local zones. Electrical contacts between cell layers helps to switch between two opposing sets of ongoing neuronal and muscle activity (favoring either AVA + class A activity, or AVB + class B activity) to allow one set to predominate. Thus, sustained waves of signals pass along the nerve cord and muscles in one direction but not the other (Kawano et al., 2011; Liu et al., 2017). GapjunctFIG 7: Gap junctions function within and between layers to influence motor output. Sense cells in head and tail synapse onto command interneurons of the ventral nerve cord, which in turn synapse onto motor neurons that make NMJs onto bodywall muscles. Cells are grouped by class into four layers (sensory/interneuron/motor neuron/muscle). Gap junctions occur selectively between these layers, but are more prominent within each layer. While most Gap junctions link homologous neurons (often bilateral pairs), there are cases where they link cells of opposing behaviors (PVC to AVA, A to B). Triangles represent sensory neurons, hexagons represent interneurons, circles represent motor neurons, and rhomboids represent bodywall muscles. 4.4.1.1 "Hub and spoke" gap junction system A variety of gap junctions has been noted for a pheromone-sensing circuit in the adult hermaphrodite nerve ring (Macosko et al., 2009) (GapjunctFIG 8). Here a single pair of interneurons (RMGL, RMGR) are connected to different sensors in the nose. Most connections rely on gap junctions (only) between the sensor and the interneuron (hub), though there are exceptions where chemical synapses sit parallel to electrical connections. The RMG interneurons become the key for balancing sensory inputs (Macosko et al., 2009). For instance, RMG integrates reception for several pheromones, detected by different receptor neurons, influencing the animal�s response, where reception of any single pheromone is generally not sufficient to evoke a response (Jang et al., 2012). RMG then contacts many downstream neurons in the nerve ring and ventral cord, mostly via chemical synapses, to organize responses to those stimuli. GapjunctFIG 8: "Hub and spoke" gap junction system. Cells are ordered into four layers to emphasize information flow from sensors to two subgroups of interneurons, and then to motor neurons and muscles (cf. Macosko et al, 2009). Some connections utilize both chemical (arrows) and electrical contacts in parallel, but in many cases gap junctions (shown in red) are the only direct link between nonequivalent cells in this circuit. The hub interneuron is thought to gather/compare different sensory stimuli in a common path before allowing that information to flow either directly to head muscles, or to the command interneurons (AVA, AVB) of the ventral nerve cord. Triangles represent sensory neurons, hexagons represent interneurons, circles represent motor neurons, and rhomboids represent bodywall muscles. 4.4.1.2 Connections between "head and tail" Most sensory neurons in the nematode have ciliated endings in either the nose or the extreme tail tip. However, the touch neuron sensors (ALM, PLM, AVM, PVM) for mild body touch have long sensory dendrites embedded in the bodywall, with receptive territories spanning up to half the body length (Chalfie et al., 1985). Inputs from anterior vs posterior stimuli are compared by pairs of interneurons, particularly the BDUs and command interneurons of the ventral cord, which are in position to compare the relative strength of touch stimuli received from either half of the body. While some synapses from sensors to these interneurons are chemical, several involve only gap junctions. Interestingly, BDU interneurons receive major gap junction inputs from anterior ALMs, and from long processes of the posterior PLMs in a unique lateral position close to the vulva (Zhang et al., 2013). Wnt signaling informs the development and targeting of lengthy PLM and BDU process extensions to bring the two classes together in a unique locale, where processes stop upon forming one large gap junction per side (BDUL to PLML, BDUR to PLMR). These isolated gap junctions were only discovered recently. Their connections are far removed from the influence of other neurons, away from the major nerve cords. How BDUs handle these different inputs from ALM and PLM is worthy of further study. Their chemical synapses are few, and concentrated in the nerve ring with rather diverse targets. Alternately, BDU might not be comparing touch dendrite inputs, but perhaps modulating excitability of two classes of sensors, ALM and PLM, via these electrical synapses. 4.4.2 Synapses within a layer Gap junctions commonly link multiple members of a neuron class, including left/right cell pairs in any layer (sensory cell pairs; interneuron pairs; motor neuron groups). Although chemical synapses can also play a similar role, gap junctions often predominate. Given the sparse network, we surmise that such gap junctions can equalize and/or prolong the activity in left/right pairs. They may also compensate where new stimuli have arisen unequally (in terms of sidedness), or even where some chemical synapses are missing or nonfunctional in the overall network. These recurrent contacts within layers are notable (Jarrell et al., 2012). Furthermore, except in special cases, left/right differences in cell activity between homologues are apparently rare in C. elegans. 4.4.2.1 Left/right balance and signal prolongation A few left/right pairs of sensory neurons are known to respond to different types of external signals. ASEL vs. ASER is the best known example (Luo et al., 2014; Bargmann, 2006). These chemosensory neurons in the nose detect different salts and water-soluble compounds in the animal�s external environment, and are involved in chemotaxis behaviors. ASEL responds primarily to sodium, whereas ASER responds better to chloride and potassium. Interestingly, these two neurons are among the few bilateral homologues in the entire adult connectome that apparently do not form any gap junctions to one another (Altun et al., 2009). This circumstance reinforces the idea that gap junctions underlie synchronization, whereas the two ASE sensors probably operate independently to provide the animal with separable responses to different ions. Another pair of olfactory neurons, AWCL/AWCR, have well described gap junctions in the lateral ganglia involving their somata in the late embryo and early L1 larva (see Section 3 Development), but later lose these connections to ASH somata (encoded by the innexin nsy-5) in the adult. These gap junctions are required during the time when the two AWC neurons adopt different cell fates, but are not present in adults, after their olfactory preferences have diverged (Chuang et al., 2007). Either AWC cell can adopt either cell fate, depending on a cascade of signaling involving this gap junction, but when nsy-5 is mutated, the two AWCs can chose identical cell fates. Given the small number of cells available, most sensory cells in C. elegans must respond to multiple extracellular signals (Bargmann, 2006; Rengarajan et al., 2016), unlike in higher animals, where sensory neurons are abundant, and each can express a single receptor type (Malnic et al., 1999). This is not feasible in C. elegans, where the typical sensory neuron expresses many different receptors. Perhaps the more surprising aspect is that so often sensory cell pairs still share gap junctions to their bilateral homologue, since they might have acquired more diverse sensory capabilities if more bilateral sensors could operate separately. 4.4.2.2 Motor neurons Within the motor neuron layer, gap junctions are again prominent. In the nerve ring, small groups of homologues are coupled by gap junctions to allow coordinated activity; examples include the RMEs, RMDs and a few more. Gap junctions are also common between non-homologues among the sublateral motor neurons, such as SMB to SAA and SMD to RMD. Gap junctions are prominent among motor neurons that lie in sequential fashion along the length of the body in the two major motor nerves, the ventral and dorsal cords (GapjunctFIG 9) (White et al., 1986; Haspel and O'Donovan, 2012). Each motor nerve cord contains sets of 5-12 equivalent neurons each for several classes of motor cells, most having excitatory action onto bodywall muscles. Each excitatory motor neuron has a limited range along the body where it forms chemical neuromuscular junctions. Their ranges do not overlap within a given class, but instead motor neuron axons typically form a single gap junction at the limit of their range onto the next motor axon of the same type (but do not form any chemical synapses between these pairings). In some cases, gap junctions are also formed at the extended limits of their dendrites. Thus, signals can be conducted along the motor nerves as separate streams for each class of motor cell, some of which underlie waves of contraction propagating from head to tail (class B excitors, including DB, VB), while others propagate signals from tail to head (class A excitors, including DA, VA). GapjunctFIG 9: Gap junctions connect a linear array of homologous VA motor neurons. A single VA neuron produces neuromuscular junctions (dark triangles) at any region along the A/P axis in the ventral nerve cord, with gap junctions (red lines) occurring exactly at the neuromuscular junction active zone limits between each successive VA motor axon along the chain. Open triangles represent dendritic inputs to each neuron. Several other classes of motor axons in the nerve cords have a similar organization of neuromuscular junction output zones delimited by gap junctions to their neighboring homologues, from head to tail. Anterior of the animal is to the left.
5 References Abdus-Saboor, I., Mancuso, V.P., Murray, J.I., Palozola, K., Norris, C., Hall, D.H., Howell, K., Huang, K. and Sundaram, M.V. 2011. Notch and Ras promote sequential steps of excretory tube development in C. elegans. Development 138: 3545-55. Article Albertson, D.G. and Thomson, J.N. 1984. The pharynx of C. elegans. Phil. Trans. Royal Soc. London 275B: 299-325. Article Altun, Z.F., Chen, B., Wang, Z-W. and Hall, D. H.. 2009. High resolution map of Caenorhabditis elegans gap junction proteins. Dev. Dyn. 238: 1936-1950. Article Avery, L. and Horvitz, H.R. 1989. Pharyngeal pumping continues after laser killing of the pharyngeal nervous system of C. elegans. Neuron 3:473-485. Abstract Bao, L., Samuels, S., Locovei, S., Macagno, E.R., Muller, K.J. and Dahl, G. 2007. Innexins form two types of channels. FEBS Letters 581: 5703-08. Article Baranova, A, Ivanov, D., Petrash, N., Skoblov, M., Kelmanson, I., Shagin, D., Nazarenko, S., Geraymovych, E., Litvin, O., Tiunova, A., Born, T.L., Usman, N., Staroverov, D., Lukyanov, S. and Panchin, Y. 2004. The mammalian pannexin family is homologous to the invertebrate innexin gap junction proteins. Genomics 83: 706-716. Abstract Bargmann, C.I. 2006. Chemosensation in C. elegans. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.123.1. Article Bischoff, M. and Schnabel, R. 2006. Global cell sorting is mediated by local cell-cell interactions in the C. elegans embryo. Dev. Biol. 294: 432-44. Article Bouhours, M., Po, M.D., Gao, S., Hung, W., Li, H., Georgiou, J., Roder, J.C. and Zhen, M. 2011. A co-operative regulation of neuronal excitability by UNC-7 innexin and NCA/NALCN leak channel. Mol. Brain 4: 1-16. Article Bruzzone, R., Hormuzdi, S.G., Barbe, M.T., Herb, A. and Monyer, H. 2003. Pannexins, a family og gap junction proteins expressed in brain. PNAS 100: 13644-13649. Article Buechner, M., Hall, D.H., Bhatt, H. and Hedgecock, E.M. 1999. Cystic canal mutants in C. elegans are defective in the apical membrane domain of the renal (excretory) cell. Dev. Biol. 214: 227-241. Abstract Byrd, D.T., Knobel, K., Affeldt, K., Crittenden, S.L. and Kimble, J. 2014. A DTC niche plexus surrounds the germline stem cell pool in C. elegans. PLOS ONE. Article Chalfie, M., Sulston, J.E., White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1985. The neural circuit for touch sensitivity in Caenorhabditis elegans. J. Neurosci. 5: 956-964. Article Chiu, Y.H., Ravichandran, K.S. and Bayliss, D.A. 2014. Intrinsic properties and regulation of pannexin 1 channel. Channels 8: 103-109. Article Chuang, C-F., VanHoven, M. K., Fetter, R. D., Verselis, V. K. and Bargmann, C. I. 2007. An innexin-dependent network establishes left-right neuronal asymmetry in C. elegans. Cell. 129: 787-799. Article Cook, Britten, Jarrell, Wang, Bloniarz, Yakovlev, Nguyen, Tang, Bayer, Buelow, Hobert, Hall and Emmons. 2018. Whole-animal connectomes of the two adults sexes of Caenorhabditis elegans. In prep. del Castillo, J., Rivera, A., Sol�rzano, S. and Serrato, J. 1989. Some aspects of the neuromuscular system of Ascaris. Exp. Physiol. 74: 1071-87. Article Emmons, S.W. 2016. Connectomics, the Final Frontier. Curr. Top. Dev. Biol. 116: 315-30. Article Faumont, S., Lindsay, T.H. and Lockery, S.R. 2012. Neuronal microcircuits for decision making in C. elegans. Curr. Opin. Neurobiol. 22: 580-91. Abstract Goldberg, G.S., Valiunas, V. and Brink, P.R. 2004. Selective permeability of gap junction channels. Biochim. Biophys. Acta 1662: 96-101. Article Hall D.H. 1977. �The posterior nervous system of the nematode Caenorhabditis elegans.� Ph.D. thesis. California Institute of Technology, Pasadena. Hall D.H. 1987. Freeze-fracture and freeze-etch studies of the nematode Caenorhabditis elegans. Ann. N.Y. Acad. Sci. 494: 215�217. Abstract Hall, D.H. and Altun, Z. 2008. C. elegans Atlas. Cold Spring Harbor Laboratory Press, New York. pp348. Abstract Hall, D.H. 2016. Gap junctions in C. elegans: their roles in behavior and developmentl. Dev. Neurobiol. doi: 10.1002/dneu.22408. Article Hall, D.H. 2017. The role of gap junctions in the C. elegans connectome. Neurosci. Lett. S0304-3940(17)30736-X. Abstract Hall, D.H. and Russell, G.J. 1991. The posterior nervous system of the nematode Caenorhabditis elegans: Serial reconstruction of identified neurons and complete pattern of synaptic interactions. J. Neurosci. 11: 1-22. Article Hall, D.H., Winfrey, V.P., Blauer, G., Hoffman, L.H., Rose, K.L., Furuta, T., Hobert, O. and Greenstein, D. 1999. Ultrastructural features of the adult hermaphrodite gonad of Caenorhabditis elegans: Relations between the germ line and soma. Dev. Biol. 212: 101-123. Article Haspel, G. and O'Donovan, M.J. 2012. A connectivity model for the locomotor network of C. elegans. Worm 1: 125-8. Article Jang, H., Kim, K., Neal, S.J., Macosko, E., Kim, D., Butcher, R.A., Zeiger, D.M., Bargmann, C.I. and Sengupta, P. 2012. Neuromodulatory state and sex specify alternative behaviors through antagonistic synaptic pathways in C. elegans. Neuron 75: 585-92. Article Jarrell, T.A., Wang, Y., Bloniarz, A.E., Brittin, C.A., Xu, M., Thomson, J.N., Albertson, D.G., Hall, D.H. and Emmons, S.W. 2012. The connectome of a decision making neuronal network. Science 337: 437-444. Abstract Kawano, T., Po, M.D., Gao, S., Leung, G., Ryu, W.S. and Zhen, M. 2011. An imbalancing act: gap junctions reduce the backward motor circuit activity to bias C. elegans for forward locomotion, Neuron 72: 572-586. Article Kim, B. and Emmons, S.W. 2017. Multiple conserved cell adhesion protein interactions mediate neural wiring of a sensory circuit in C. elegans. eLife 2017;6:e29257. Article Koeppen, M., Simske, J., Sims, P., Firestein, B.L., Hall, D.H., Radice, A., Rongo, C. and Hardin, J. 2001. Cooperative regulation of AJM-1 controls junctional integrity in Caenorhabditis elegans epithelia. Nature Cell Biol. 3: 983-991. Abstract Koval, M., Molina, S.A. and Burt, J.M. 2014. Mix and match: Investigating heteromeric and heterotypic gap junction channels in model systems and native tissues. FEBS Lett. 588:11931204. Article Lane, N.J., Skaer, H.L. and Swales, L.S. 1977. Intercellular junctions in the central nervous system of insects. J. Cell Sci. 26: 175-99. Article Liu, P., Chen, B. and Wang Z-W. 2011. Gap junctions synchronize action potentials and Ca2+ transients in C. elegans body wall muscles. JBC 286: 44285-93. Article Liu, P., Chen, B., Altun, Z.F., Gross, M.J., Shan, A., Schuman, B., Hall, D.H. and Wang, Z-W. 2013. Six innexins contribute to electrical coupling of C. elegans body-wall muscle. PLoS ONE 8: e76877. Article Liu, P., Chen, B., Mailler, R. and Wang, Z.-W. 2017. Antidromic-rectifying gap junctions amplify chemical transmission at functionally mixed electrical-chemical synapses. Nat. Com. 8: 14818. Article Liu, Q., Chen, B., Gaier, E., Joshi, J. and Wang, Z-W. 2006. Low conductance gap junctions mediate specific electrical coupling in the body wall muscle cells of C. elegans. J Biol. Chem. 281: 7881-9. Article Liu, S.J. and Zukin, R.S. 2007. Ca2+ permeable AMPA receptors in synaptic plasticity and neuronal death. Trends Neurosci. 30: 126-34. Abstract Luo, L., Wen, Q., Ren, J., Hendricks, M., Gershow, M., Qin, Y., Greenwood, J., Soucy, E.R., Klein, M., Smith-Parker, H.K., Calvo, A.C., Col�n-Ramos, D.A., Samuel, A.D. and Zhang, Y. 2014. Dynamic encoding of perception, memory, and movement in a C. elegans chemotaxis circuit. Neuron 82: 1115-28. Article Macosko, E.Z., Pokala, N., Feinberg, E.H., Chalasani, S.H., Butcher, R.A., Clardy, J. and Bargmann, C.I. 2009. A hub-and-spoke circuit drives pheromone attraction and social behavior in C. elegans. Nature 458: 1171-5. Article Malnic, B., Hirono, J., Sato, T., and Buck, L.B. 1999. Combinatorial receptor codes for odors. Cell 96: 713-23. Article Mancuso, V.P., Parry, J.M., Storer, L., Poggioli, C., Nguyen, K.C., Hall, D.H. and Sundaram, M.V. 2012. Extracellular leucine-rich repeat proteins are required to organize the apical extracellular matrix and maintain epithelial junction integrity in C. elegans. Development 139: 979-990. Abstract Norman, K.R. and Villu Maricq, A. 2007. Innexin function: Minding the gap junction. Curr. Biol. 17: R812-R814. Article Nguyen, C.Q., Hall, D.H., Yang, Y. and Fitch, D.H.A. 1999. Morphogenesis in the male tail tip of Caenorhabditis elegans. Dev. Biol. 207: 86-106. Article Oshima, A., Matsuzawa, T., Nishikawa, K. and Fujiyoshi, Y. 2013. Oligomeric structure and functional characterization of the C. elegans innexin-6 gap junction protein. J. Biol. Chem. 288: 10513-21. Article Oshima, A., Matsuzawa, T., Murata, K., Tani, K. and Fujiyoshi, Y. 2016. Hexadecameric structure of an invertebrate gap junction channel. J. Mol. Biol. 428: 1227-1236. Article Penuela, S., Gehl, R. and Laird, D.W. 2013. The biochemistry and function of pannexin channels. BBA-Biomembranes 1828: 15-22. Article Peters, M.A., Teramoto, T., White, J.Q., Iwasaki, K. and Jorgensen, E.M. 2007. A calcium wave mediated by gap junctions coordinates a rhythmic behavior in C. elegans. Curr. Biol. 17: 1601-08. Article Phelan, P. and Starich, T.A. 2001. Innexins get into the gap. Bioessays 23: 388-396. Abstract Qadota, H., Matsunaga, Y., Nguyen, K.C.Q., Mattheyse, A., Hall, D.H. and Benian, G.M. 2017. High-resolution imaging of muscle attachment structures in Caenorhabditis elegans. Cytoskeleton 74: 426-442. Abstract Quick, D.C. and Johnson, R.G. 1977. Gap junctions and rhombic particle arrays in planaria. J. Ultrastr. Res. 60: 348-61. Abstract Raizen, D.M., Lee, R.Y.N. and Avery, L. 1995. Interacting genes required for pharyngeal excitation by motor neuron MC in Caenorhabditis elegans. Genetics 141: 1365-1382. Article Retamal, M.A. and Saez, J.C. 2014. Hemichannels: from the molecule to the function. Front. Physiol. 5: 411. Article Revel, J.P. and Karnovsky, M.J. 1967. Hexagonal array of subunits in intercellular junctions of the mouse heart and liver. J. Cell Biol. 33: C7-C12. Article Rengarajan, S. and Hallem, E.A. 2016. Olfactory circuits and behaviors of nematodes. Curr. Opin. Neurobiol. 41: 136-148. Abstract Richter, K., Kiefer, K.P., Grzesik, B.A., Clauss, W.G. and Fronius, M. 2014 Hydrostatic pressure activates ATP-sensitive K+ channels in lung epithelium by ATP release through pannexin and connexin hemichannels. The FASEB Journal 28: 45-55. Article Rodenas-Ruano, A., Chavez, A.E., Cossio, M.J., Castillo, P.E. and Zukin, R.S. 2012. REST-dependent epigenetic remodeling promotes the developmental switch in synaptic NMDA receptors. Nat. Neurosci. 15: 1382-90. Article Simonsen, K.T., Moerman, D.G. and Naus, C.C. 2014. Gap junctions in C. elegans. Front. Physiol. 5: 40. Article Sosinsky, G.E., Boassa, D., Dermietzel, R., Duffy, H.S., Laird, D.W., MacVicar, B., Naus, C.C., Penuela, S., Scemes, E., Spray, D.C., Thompson, R.J., Zhao, H.B. and Dahl, G. 2011. Pannexin channels are not gap junction hemichannels. Channels 5: 193-197. Article Staehelin, L.A. 1974. Structure and function of intercellular junctions. Int. Rev. Cytol. 39: 191-283. Abstract Starich, T.A., Lee, R.Y., Panzarella, C., Avery, L. and Shaw, J.E. 1996. eat-5 and unc-7 represent a multigene family in Caenorhabditis elegans involved in cell-cell coupling. J. Cell Biol. 134: 537-548. Article Starich, T.A., Miller, A. Nguyen, R.L., Hall, D.H. and Shaw, J.E. 2003. The Caenorhabditis elegans innexin INX-3 is localized to gap junctions and is essential for embryonic development. Dev. Biol. 256:403-417. Article Starich, T.A., Hall, D.H. and Greenstein, D. 2014. Two classes of gap junction channels mediate soma-germline interactions essential for germline proliferation and gametogenesis in Caenorhabditis elegans. Genetics 198: 1127-53. Article Stein, K.K. and Golden, A. 2015. The C. elegans eggshell. WormBook, ed. The C. elegans Research Community, WormBook, doi/10.1895/wormbook.1.179.1 Article Stone, C.E., Hall, D.H. and Sundaram, M.V. 2009. Lipocalin signaling controls unicellular tube development in the Caenorhabditis elegans excretory system. Dev. Biol. 15: 201-11. Article Stretton, A.O., Fishpool, R.M., Southgate, E., Donmoyer, J.E., Walrond, J.P., Moses, J.E. and Kass, I.S. 1978. Structure and physiological activity of the motoneurons of the nematode Ascaris. 75: 3493-7. Article Sulston, J.E., Albertson, D.G. and Thomson, J.N. 1980. The Caenorhabditis elegans male: postembryonic development of nongonadal structures. Dev Biol. 78: 542-576. Article Trojanowski, N.F. and Fang-Yen, C. 2015. Simultaneous optogenetic stimulation of individual pharyngeal neurons and monitoring of feeding behavior in intact C. elegans. Methods Mol. Biol. 1327: 105-19. Article Trojanowski, N.F., Raizen, D.M. and Fang-Yen, C. 2016. Pharyngeal pumping in C. elegans depends on tonic and phasic signaling from the nervous system. Sci. Rep. 6: 22940. Article Varshney, L.R., Chen, B.L., Paniagua, E., Hall, D.H. and Chklovskii, D.B. 2011. Structural properties of the Caenorhabditis elegans neuronal network. PLoS Comput. Biol. 7: e1001066. Article Walker, D.S. and Schafer, W.R. 2020. Distinct roles for innexin gap junctions and hemichannels in mechanosensation. 9. pii: e50597. doi: 10.7554/eLife.50597. Article White J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1976. The structure of the ventral nerve cord of Caenorhabditis elegans. Philos. Trans. R. Soc. Lond. Series B. Biol. Sci. 275B: 327-348. Article White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1986. The structure of the nervous system of the nematode C. elegans. Philos. Trans. R. Soc. Lond. Series B. Biol. Sci. 314: 1-340. Article White, T.W. 2003. Nonredundant gap junction functions. Physiology 18: 95-99. Article Zhang, J., Li, X., Jevince, A.R., Guan, L., Wang, J., Hall, D.H., Huang, X. and Ding, M. 2013. Neuronal target identification requires AHA-1-mediated fine-tuning of Wnt signaling in C. elegans. PLoS Genetics 9: e1003618. Article
This chapter should be cited as: Hall, D.H. 2018. Gap junctions. In WormAtlas. doi:10.3908/wormatlas.1.25 We thank Chris Crocker for his help in preparing the figures. Edited for the web by Laura A. Herndon. Last revision: February 19. 2020.

�Copyright 2024 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |